documentationtools.ReSTDirective
================================

.. abjad-lineage:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective

.. autoclass:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.append
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.argument
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.children
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.depth
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.depthwise_inventory
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.directive
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.extend
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.graph_order
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.improper_parentage
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.index
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.insert
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.leaves
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.name
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.node_class
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.nodes
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.options
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.parent
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.pop
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.proper_parentage
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.remove
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.rest_format
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.root
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__contains__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__copy__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__deepcopy__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__delitem__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__eq__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__getitem__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__getstate__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__iter__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__len__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__ne__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__repr__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__setitem__
      ~abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__setstate__

Bases
-----

- :py:class:`datastructuretools.TreeContainer <abjad.tools.datastructuretools.TreeContainer.TreeContainer.TreeContainer>`

- :py:class:`datastructuretools.TreeNode <abjad.tools.datastructuretools.TreeNode.TreeNode.TreeNode>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.children
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.directive
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.leaves
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.node_class
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.nodes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.options
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.rest_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.root
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.argument
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.append
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.extend
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.index
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.insert
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.pop
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.remove
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__contains__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__copy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__delitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__getitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__getstate__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__iter__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__len__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__setitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTDirective.ReSTDirective.ReSTDirective.__setstate__
   :noindex:
